==> owncloud-8.1.0p2.tgz: owncloud/apps/user_ldap/l10n/bn_BD.js <==
OC.L10N.register(
    "user_ldap",
    {
    "Failed to clear the mappings." : "মানচিত্রায়ন মুছতে ব্যার্থ হলো।",
    "Failed to delete the server configuration" : "সার্ভার কনফিগারেশন মোছা ব্যার্থ হলো",
    "The configuration is valid and the connection could be established!" : "কনফিগারেশনটি বৈধ এবং যোগাযোগ প্রতিষ্ঠা করা যায়!",
    "The configuration is valid, but the Bind failed. Please check the server settings and credentials." : "কনফিগারেশনটি বৈধ তবে Bind ব্যার্থ। দয়া করে সার্ভার নিয়ামকসমূহ এবং ব্যবহারকারী পরীক্ষা করুন।",
    "The configuration is invalid. Please have a look at the logs for further details." : "কনফিহারেশনটি অবৈধ। বিস্তারিত জানতে দয়া করে লগ দেখুন।",
    "No action specified" : "কোন কার্যাদেশ সুনির্দিষ্ট নয়",
    "No configuration specified" : " কোন কনফিগারেসন সুনির্দিষ্ট নয়",
    "No data specified" : "কোন ডাটা সুনির্দিষ্ট নয়",
    " Could not set configuration %s" : "%s কনফিগারেসন ঠিক করা গেল না",
    "Configuration incorrect" : "ভুল কনফিগারেসন",
    "Configuration incomplete" : "অসম্পূর্ণ কনফিগারেসন",
    "Configuration OK" : "কনফিগারেসন ঠিক আছে",
    "Select groups" : "গ্রুপ নির্ধারণ",
    "Select object classes" : "অবজেক্ট ক্লাস নির্ধারণ",
    "{nthServer}. Server" : "{nthServer}. সার্ভার",
    "Do you really want to delete the current Server Configuration?" : "আপনি কি সত্যিই চলতি সার্ভার কনফিগারেসন মুছতে চান?",
    "Confirm Deletion" : "মোছার আদেশ নিশ্চিত করুন",
    "Select attributes" : "বৈশিষ্ট্য নির্ধারণ",
    "_%s group found_::_%s groups found_" : ["%s গ্রুপ পাওয়া গেছে","%s গ্রুপ পাওয়া গেছে"],
    "_%s user found_::_%s users found_" : ["%s ব্যাবহারকারী পাওয়া গেছে","%s ব্যাবহারকারী পাওয়া গেছে"],
    "Could not find the desired feature" : "চাহিদামাফিক ফিচারটি পাওয়া গেলনা",
    "Invalid Host" : "অবৈধ হোস্ট",
    "Server" : "সার্ভার",
    "Users" : "ব্যবহারকারী",
    "Groups" : "গোষ্ঠীসমূহ",
    "Test Configuration" : "পরীক্ষামূলক কনফিগারেসন",
    "Help" : "সহায়িকা",
    "Groups meeting these criteria are available in %s:" : "প্রদত্ত বৈশিষ্ট্য অনুযায়ী %s এ প্রাপ্তব্য গ্রুপসমূহ:",
    "The filter specifies which LDAP groups shall have access to the %s instance." : "ফিল্টারটি %s সার্ভারে কোন কোন LDAP গ্রুপ প্রবেশাধিকার পাবে তা নির্ধারণ করে।",
    "Other Attributes:" : "অন্যান্য বৈশিষ্ট্য:",
    "Defines the filter to apply, when login is attempted. %%uid replaces the username in the login action. Example: \"uid=%%uid\"" : "প্রবেশ প্রচেষ্টা নিলে প্রযোজ্য ফিল্টার নির্ধারণ করে। প্রবেশকালে %%uid ব্যাবহারকারীর নামকে প্রতিস্থাপন করে। ঊদাহরণ: \"uid=%%uid\"",
    "1. Server" : "1. সার্ভার",
    "%s. Server:" : "%s. সার্ভার:",
    "Host" : "হোস্ট",
    "You can omit the protocol, except you require SSL. Then start with ldaps://" : "SSL আবশ্যক  না হলে  আপনি এই প্রটোকলটি মুছে ফেলতে পারেন । এরপর শুরু করুন এটা দিয়ে ldaps://",
    "Port" : "পোর্ট",
    "User DN" : "ব্যবহারকারি  DN",
    "The DN of the client user with which the bind shall be done, e.g. uid=agent,dc=example,dc=com. For anonymous access, leave DN and Password empty." : "The DN of the client user with which the bind shall be done, e.g. uid=agent,dc=example,dc=com. পরিচয় গোপন রেখে অধিগমনের জন্য  DN এবং কূটশব্দটি ফাঁকা রাখুন।",
    "Password" : "কূটশব্দ",
    "For anonymous access, leave DN and Password empty." : "অজ্ঞাতকুলশীল অধিগমনের জন্য DN এবং কূটশব্দটি ফাঁকা রাখুন।",
    "One Base DN per line" : "লাইনপ্রতি একটি Base DN",
    "You can specify Base DN for users and groups in the Advanced tab" : "সুচারু ট্যঅবে গিয়ে আপনি ব্যবহারকারি এবং গোষ্ঠীসমূহের জন্য ভিত্তি DN নির্ধারণ করতে পারেন।",
    "Limit %s access to users meeting these criteria:" : "%s এ প্রবেশাধিকার এই শর্তধারী ব্যবহারকারীর মাঝে সীমিত রাখ:",
    "The filter specifies which LDAP users shall have access to the %s instance." : "এই ফিল্টারটি কোন কোন LDAP ব্যবহারকারী %s সার্ভারে প্রবেশ করবেন তা বাছাই করে।",
    "Back" : "পেছনে যাও",
    "Continue" : "চালিয়ে যাও",
    "Expert" : "দক্ষ",
    "Advanced" : "সুচারু",
    "<b>Warning:</b> Apps user_ldap and user_webdavauth are incompatible. You may experience unexpected behavior. Please ask your system administrator to disable one of them." : "<b>Warning:</b> Apps user_ldap and user_webdavauth কম্প্যাটিবল নয়। আপনি অবান্ছিত জটিলতার মুখোমুখি হতে পারেন। সিস্টেম প্রশাসককে যেকোন একটি অকার্যকর করে দিতে বলুন।",
    "<b>Warning:</b> The PHP LDAP module is not installed, the backend will not work. Please ask your system administrator to install it." : "<b>Warning:</b> PHP LDAP মডিউল ইনস্টল করা নেই, ব্যাকএন্ড কাজ করবেনা। সিস্টেম প্রশাসককে এটি ইনস্টল করতে বলুন।",
    "Connection Settings" : "সংযোগ নিয়ামকসমূহ",
    "Configuration Active" : "কনফিগারেসন সক্রিয়",
    "When unchecked, this configuration will be skipped." : "চেকমার্ক তুলে দিলে কনফিগারেসন এড়িয়ে যাবে।",
    "Backup (Replica) Host" : "ব্যাকআপ (নকল) হোস্ট",
    "Give an optional backup host. It must be a replica of the main LDAP/AD server." : "একটি ঐচ্ছিক ব্যাকআপ হোস্ট দিন। এটি মূল LDAP/AD সার্ভারের নকল হবে।",
    "Backup (Replica) Port" : "ব্যাকআপ (নকল) পোর্ট",
    "Disable Main Server" : "মূল সার্ভারকে অকার্যকর কর",
    "Only connect to the replica server." : "শুধুমাত্র নকল সার্ভারে সংযোগ দাও।",
    "Case insensitive LDAP server (Windows)" : "বর্ণ অসংবেদী LDAP  সার্ভার (উইন্ডোজ)",
    "Turn off SSL certificate validation." : "SSL সনদপত্র যাচাইকরণ বন্ধ রাক।",
    "Cache Time-To-Live" : "ক্যাশে টাইম-টু-লিভ",
    "in seconds. A change empties the cache." : "সেকেন্ডে। কোন পরিবর্তন ক্যাসে খালি করবে।",
    "Directory Settings" : "ডিরেক্টরি নিয়ামকসমূহ",
    "User Display Name Field" : "ব্যবহারকারীর প্রদর্শিতব্য নামের ক্ষেত্র",
    "The LDAP attribute to use to generate the user's display name." : "ব্যবহারকারীর প্রদর্শনীয় নাম তৈরি করার জন্য ব্যবহৃত LDAP বৈশিষ্ট্য।",
    "Base User Tree" : "ভিত্তি ব্যবহারকারি বৃক্ষাকারে",
    "Group Display Name Field" : "গোষ্ঠীর প্রদর্শিতব্য নামের ক্ষেত্র",
    "Base Group Tree" : "ভিত্তি গোষ্ঠী বৃক্ষাকারে",
    "Group Search Attributes" : "গ্রুপ খোঁজার বৈশিষ্ট্য",
    "Group-Member association" : "গোষ্ঠী-সদস্য সংস্থাপন",
    "Nested Groups" : "একতাবদ্ধ গোষ্ঠিসমূহ",
    "Special Attributes" : "বিশেষ বৈশিষ্ট্যসমূহ",
    "Quota Field" : "কোটা",
    "Quota Default" : "পূর্বনির্ধারিত কোটা",
    "in bytes" : "বাইটে",
    "Email Field" : "ইমেইল ক্ষেত্র",
    "Leave empty for user name (default). Otherwise, specify an LDAP/AD attribute." : "ব্যবহারকারী নামের জন্য ফাঁকা রাখুন (পূর্বনির্ধারিত)। অন্যথায়, LDAP/AD বৈশিষ্ট্য নির্ধারণ করুন।"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-8.2.2p3.tgz: owncloud/apps/user_ldap/l10n/bn_BD.js <==
OC.L10N.register(
    "user_ldap",
    {
    "Failed to clear the mappings." : "মানচিত্রায়ন মুছতে ব্যার্থ হলো।",
    "Failed to delete the server configuration" : "সার্ভার কনফিগারেশন মোছা ব্যার্থ হলো",
    "The configuration is valid and the connection could be established!" : "কনফিগারেশনটি বৈধ এবং যোগাযোগ প্রতিষ্ঠা করা যায়!",
    "The configuration is valid, but the Bind failed. Please check the server settings and credentials." : "কনফিগারেশনটি বৈধ তবে Bind ব্যার্থ। দয়া করে সার্ভার নিয়ামকসমূহ এবং ব্যবহারকারী পরীক্ষা করুন।",
    "The configuration is invalid. Please have a look at the logs for further details." : "কনফিহারেশনটি অবৈধ। বিস্তারিত জানতে দয়া করে লগ দেখুন।",
    "No action specified" : "কোন কার্যাদেশ সুনির্দিষ্ট নয়",
    "No configuration specified" : " কোন কনফিগারেসন সুনির্দিষ্ট নয়",
    "No data specified" : "কোন ডাটা সুনির্দিষ্ট নয়",
    " Could not set configuration %s" : "%s কনফিগারেসন ঠিক করা গেল না",
    "Configuration incorrect" : "ভুল কনফিগারেসন",
    "Configuration incomplete" : "অসম্পূর্ণ কনফিগারেসন",
    "Configuration OK" : "কনফিগারেসন ঠিক আছে",
    "Select groups" : "গ্রুপ নির্ধারণ",
    "Select object classes" : "অবজেক্ট ক্লাস নির্ধারণ",
    "{nthServer}. Server" : "{nthServer}. সার্ভার",
    "Do you really want to delete the current Server Configuration?" : "আপনি কি সত্যিই চলতি সার্ভার কনফিগারেসন মুছতে চান?",
    "Confirm Deletion" : "মোছার আদেশ নিশ্চিত করুন",
    "Select attributes" : "বৈশিষ্ট্য নির্ধারণ",
    "_%s group found_::_%s groups found_" : ["%s গ্রুপ পাওয়া গেছে","%s গ্রুপ পাওয়া গেছে"],
    "_%s user found_::_%s users found_" : ["%s ব্যাবহারকারী পাওয়া গেছে","%s ব্যাবহারকারী পাওয়া গেছে"],
    "Could not find the desired feature" : "চাহিদামাফিক ফিচারটি পাওয়া গেলনা",
    "Invalid Host" : "অবৈধ হোস্ট",
    "Server" : "সার্ভার",
    "Users" : "ব্যবহারকারী",
    "Groups" : "গোষ্ঠীসমূহ",
    "Test Configuration" : "পরীক্ষামূলক কনফিগারেসন",
    "Help" : "সহায়িকা",
    "Groups meeting these criteria are available in %s:" : "প্রদত্ত বৈশিষ্ট্য অনুযায়ী %s এ প্রাপ্তব্য গ্রুপসমূহ:",
    "The filter specifies which LDAP groups shall have access to the %s instance." : "ফিল্টারটি %s সার্ভারে কোন কোন LDAP গ্রুপ প্রবেশাধিকার পাবে তা নির্ধারণ করে।",
    "Other Attributes:" : "অন্যান্য বৈশিষ্ট্য:",
    "Defines the filter to apply, when login is attempted. %%uid replaces the username in the login action. Example: \"uid=%%uid\"" : "প্রবেশ প্রচেষ্টা নিলে প্রযোজ্য ফিল্টার নির্ধারণ করে। প্রবেশকালে %%uid ব্যাবহারকারীর নামকে প্রতিস্থাপন করে। ঊদাহরণ: \"uid=%%uid\"",
    "1. Server" : "1. সার্ভার",
    "%s. Server:" : "%s. সার্ভার:",
    "Host" : "হোস্ট",
    "You can omit the protocol, except you require SSL. Then start with ldaps://" : "SSL আবশ্যক  না হলে  আপনি এই প্রটোকলটি মুছে ফেলতে পারেন । এরপর শুরু করুন এটা দিয়ে ldaps://",
    "Port" : "পোর্ট",
    "User DN" : "ব্যবহারকারি  DN",
    "The DN of the client user with which the bind shall be done, e.g. uid=agent,dc=example,dc=com. For anonymous access, leave DN and Password empty." : "The DN of the client user with which the bind shall be done, e.g. uid=agent,dc=example,dc=com. পরিচয় গোপন রেখে অধিগমনের জন্য  DN এবং কূটশব্দটি ফাঁকা রাখুন।",
    "Password" : "কূটশব্দ",
    "For anonymous access, leave DN and Password empty." : "অজ্ঞাতকুলশীল অধিগমনের জন্য DN এবং কূটশব্দটি ফাঁকা রাখুন।",
    "One Base DN per line" : "লাইনপ্রতি একটি Base DN",
    "You can specify Base DN for users and groups in the Advanced tab" : "সুচারু ট্যঅবে গিয়ে আপনি ব্যবহারকারি এবং গোষ্ঠীসমূহের জন্য ভিত্তি DN নির্ধারণ করতে পারেন।",
    "Limit %s access to users meeting these criteria:" : "%s এ প্রবেশাধিকার এই শর্তধারী ব্যবহারকারীর মাঝে সীমিত রাখ:",
    "The filter specifies which LDAP users shall have access to the %s instance." : "এই ফিল্টারটি কোন কোন LDAP ব্যবহারকারী %s সার্ভারে প্রবেশ করবেন তা বাছাই করে।",
    "Back" : "পেছনে যাও",
    "Continue" : "চালিয়ে যাও",
    "Expert" : "দক্ষ",
    "Advanced" : "সুচারু",
    "<b>Warning:</b> Apps user_ldap and user_webdavauth are incompatible. You may experience unexpected behavior. Please ask your system administrator to disable one of them." : "<b>Warning:</b> Apps user_ldap and user_webdavauth কম্প্যাটিবল নয়। আপনি অবান্ছিত জটিলতার মুখোমুখি হতে পারেন। সিস্টেম প্রশাসককে যেকোন একটি অকার্যকর করে দিতে বলুন।",
    "<b>Warning:</b> The PHP LDAP module is not installed, the backend will not work. Please ask your system administrator to install it." : "<b>Warning:</b> PHP LDAP মডিউল ইনস্টল করা নেই, ব্যাকএন্ড কাজ করবেনা। সিস্টেম প্রশাসককে এটি ইনস্টল করতে বলুন।",
    "Connection Settings" : "সংযোগ নিয়ামকসমূহ",
    "Configuration Active" : "কনফিগারেসন সক্রিয়",
    "When unchecked, this configuration will be skipped." : "চেকমার্ক তুলে দিলে কনফিগারেসন এড়িয়ে যাবে।",
    "Backup (Replica) Host" : "ব্যাকআপ (নকল) হোস্ট",
    "Give an optional backup host. It must be a replica of the main LDAP/AD server." : "একটি ঐচ্ছিক ব্যাকআপ হোস্ট দিন। এটি মূল LDAP/AD সার্ভারের নকল হবে।",
    "Backup (Replica) Port" : "ব্যাকআপ (নকল) পোর্ট",
    "Disable Main Server" : "মূল সার্ভারকে অকার্যকর কর",
    "Only connect to the replica server." : "শুধুমাত্র নকল সার্ভারে সংযোগ দাও।",
    "Turn off SSL certificate validation." : "SSL সনদপত্র যাচাইকরণ বন্ধ রাক।",
    "Cache Time-To-Live" : "ক্যাশে টাইম-টু-লিভ",
    "in seconds. A change empties the cache." : "সেকেন্ডে। কোন পরিবর্তন ক্যাসে খালি করবে।",
    "Directory Settings" : "ডিরেক্টরি নিয়ামকসমূহ",
    "User Display Name Field" : "ব্যবহারকারীর প্রদর্শিতব্য নামের ক্ষেত্র",
    "The LDAP attribute to use to generate the user's display name." : "ব্যবহারকারীর প্রদর্শনীয় নাম তৈরি করার জন্য ব্যবহৃত LDAP বৈশিষ্ট্য।",
    "Base User Tree" : "ভিত্তি ব্যবহারকারি বৃক্ষাকারে",
    "Group Display Name Field" : "গোষ্ঠীর প্রদর্শিতব্য নামের ক্ষেত্র",
    "Base Group Tree" : "ভিত্তি গোষ্ঠী বৃক্ষাকারে",
    "Group Search Attributes" : "গ্রুপ খোঁজার বৈশিষ্ট্য",
    "Group-Member association" : "গোষ্ঠী-সদস্য সংস্থাপন",
    "Nested Groups" : "একতাবদ্ধ গোষ্ঠিসমূহ",
    "Special Attributes" : "বিশেষ বৈশিষ্ট্যসমূহ",
    "Quota Field" : "কোটা",
    "Quota Default" : "পূর্বনির্ধারিত কোটা",
    "in bytes" : "বাইটে",
    "Email Field" : "ইমেইল ক্ষেত্র",
    "Leave empty for user name (default). Otherwise, specify an LDAP/AD attribute." : "ব্যবহারকারী নামের জন্য ফাঁকা রাখুন (পূর্বনির্ধারিত)। অন্যথায়, LDAP/AD বৈশিষ্ট্য নির্ধারণ করুন।",
    "Backup (Replica) Host" : "ব্যাকআপ (নকল) হোস্ট",
    "Backup (Replica) Port" : "ব্যাকআপ (নকল) পোর্ট"
},
"nplurals=2; plural=(n != 1);");
